package Perl6::Cookbook;

use strict;
use warnings;

use 5.008;

our $VERSION = '0.05';

=head1 NAME

Perl6::Cookbook - The Perl Cookbook examples implemented in Perl 6

=head1 SYNOPSIS

After installation run the C<perl6_cookbook> script to find out 
where were the examples installed.

=head1 DESCRIPTION

See also Rakudo Feature status:
L<http://www.perlfoundation.org/perl6/index.cgi?rakudo_feature_status>

=head1 COPYRIGHT

Copyright 2009 Gabor Szabo. L<http://www.szabgab.com/>

=head1 LICENSE

This program is free software; you can redistribute it and/or
modify it under the same terms as Perl 5 itself.

=cut

1;
